/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is Soyapi Mumba.
 *
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 
var SWService = function(aServiceId) {
    this.prefs = Components.classes["@mozilla.org/preferences-service;1"].
                getService(Components.interfaces.nsIPrefService);  
    this.swPrefs = this.prefs.getBranch("extensions.searchwith.");
    //this.svcPrefs = this.prefs.getBranch("extensions.searchwith.service-list.");				
    this.swServices = SearchWith.getServices(); //this.svcPrefs.getChildList("", {});	 
    this.serviceId = aServiceId;

    this.getName = function() 
    {
        var name = "";
		switch (this.serviceId) {
			case "url":
				name = SearchWith.getPropString("address.bar", "searchwith-strings");
				break;
				
			case "all":
				name = SearchWith.getPropString("all", "searchwith-strings");
				break;
			
			default:
				try {
					name = this.swPrefs.getComplexValue("service."+this.serviceId+".label",
								Components.interfaces.nsISupportsString).data;
				} catch(e) {
					name = "";
				}	
		}
		
        return name;
	}
    
	this.getEngineId = function() 
    {
        try {
            return this.swPrefs.getComplexValue("service."+this.serviceId+".engine",
                            Components.interfaces.nsISupportsString).data;
        } catch(e) {
            return "";
        }
	}
    
	this.getEngineName = function() 
    {
        var anEngine = new SWEngine(this.getEngineId());
        return anEngine.getName();
	}
    
    this.isEnabled = function() 
    {
        return (this.getEngineId().trim().length > 0);
    }
    
    this.setName = function(aName) 
    {
		var suppStr = Components.classes["@mozilla.org/supports-string;1"].createInstance(
									Components.interfaces.nsISupportsString);
		suppStr.data = aName;
        try {
            this.swPrefs.setComplexValue("service."+this.serviceId+".label",
                                Components.interfaces.nsISupportsString, suppStr);
        } catch(e) {
        }
    }
	
	this.setEngineId = function(anEngineId) 
    {
		var suppStr = Components.classes["@mozilla.org/supports-string;1"].createInstance(
									Components.interfaces.nsISupportsString);
		suppStr.data = anEngineId;
        try {
            this.swPrefs.setComplexValue("service."+this.serviceId+".engine",
                                Components.interfaces.nsISupportsString, suppStr);
        } catch(e) {
        }
	}
	
	this.countEngines = function() 
    {
		var allEngines = SearchWith.getEngines();
		var engineNum = 0;
		for (each in allEngines) {
			var thisEngine = new SWEngine(allEngines[each]);
			if (thisEngine.getServiceId() == this.serviceId) {
                engineNum++;
			}
		}
		return engineNum;
	}
    
    this.addToList = function() 
    {
        var swServices = SearchWith.getServices();
        swServices.push(this.serviceId);
        
        var suppStr = Components.classes["@mozilla.org/supports-string;1"].createInstance(
									Components.interfaces.nsISupportsString);
        suppStr.data = swServices.join(",");
        try {
            this.swPrefs.setComplexValue("service-list",
                                Components.interfaces.nsISupportsString, suppStr);
        } catch(e) {
        }
    }
  
};
